==> karot_components-0.0.3.tar.gz: lib/cell/cell_product.dart <==
// ignore_for_file: constant_identifier_names

import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:flutter_placeholder_textlines/placeholder_lines.dart';
import 'package:karot_components/button/karot_icon_button.dart';
import 'package:karot_components/constant/button_enum.dart';
import 'package:karot_components/constant/text_enum.dart';
import 'package:karot_components/constant/text_style.dart';
import 'package:karot_components/constant/theme.dart';
import 'package:karot_components/label/karot_label.dart';

class KRCellProduct extends StatelessWidget {
  final String imgURL;
  final String title;
  final String caption;
  final String subtitle;
  final bool isFavorite;
  final EdgeInsetsGeometry padding;
  final int backgroundDiscountColor;
  final int backgroundFavoriteColor;
  final int textColor;
  final String? cartCountText;
  final String? discountText;

  const KRCellProduct({
    Key? key,
    this.imgURL = "http://via.placeholder.com/350x150",
    required this.title,
    required this.subtitle,
    required this.caption,
    this.isFavorite = false,
    this.padding = const EdgeInsets.all(KRTheme.PADDING_NORMAL),
    this.backgroundFavoriteColor = KRTheme.DEFAULT_PRIMARY_LIGHT_COLOR,
    this.backgroundDiscountColor = KRTheme.DEFAULT_PRIMARY_COLOR,
    this.cartCountText,
    this.discountText,
    this.textColor = KRTheme.DEFAULT_DARK_COLOR,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      width: 150,
      height: 200,
        padding: padding,
        child: Stack(children: [
          Column(
            mainAxisAlignment: MainAxisAlignment.start,
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              SizedBox(
                height: 150,
                child: CachedNetworkImage(
                  imageUrl: imgURL,
                  placeholder: (context, url) =>
                      const PlaceholderLines(count: 1, lineHeight: 8),
                  errorWidget: (context, url, error) => const Icon(Icons.error),
                ),
              ),
              const SizedBox(height: 10),
              KRLabel(
                  padding: const EdgeInsets.only(left: 10),
                  text: title,
                  isBold: true,
                  size: KRTextSize.body,
                  textAlign: TextAlign.left),
              KRLabel(
                  padding: const EdgeInsets.only(left: 10),
                  text: caption,
                  isBold: false,
                  textColor: KRTheme.DEFAULT_GREY_COLOR,
                  size: KRTextSize.caption,
                  textAlign: TextAlign.left),
              KRLabel(
                  padding: const EdgeInsets.only(left: 10),
                  text: subtitle,
                  isBold: false,
                  size: KRTextSize.body,
                  textAlign: TextAlign.left),
            ],
          ),
          discountText != null ? Positioned(
              left: 5,
              top: 0,
              child: Container(
                  decoration: BoxDecoration(
                      color: Color(backgroundDiscountColor),
                      borderRadius: BorderRadius.circular(10)),
                  padding: const EdgeInsets.all(KRTheme.PADDING_SMALL),
                  child: Text(
                    "30%\nOFF",
                    textAlign: TextAlign.center,
                    style: TStyle.textText(
                        color: const Color(KRTheme.DEFAULT_LIGHT_COLOR),
                        isBold: true,
                        fontSize: KRTextSize.caption),
                  ))) : const SizedBox(),
          Positioned(
              right: -5,
              top: -5,
              child: KRIconButton(
                  backgroundColor: backgroundFavoriteColor,
                  color: isFavorite ? KRTheme.DEFAULT_PRIMARY_COLOR :  KRTheme.DEFAULT_DARK_COLOR,
                  iconData: isFavorite ? Icons.favorite : Icons.favorite_border_sharp,
                  isOutline: false,
                  size: KRButtonSize.small,
                  onPress: () {})),
          Positioned(
              right: 0,
              top: 110,
              child: KRIconButton(
                text: cartCountText,
                  isCirle: false,
                  backgroundColor: KRTheme.DEFAULT_PRIMARY_LIGHT_COLOR,
                  color: KRTheme.DEFAULT_DARK_COLOR,
                  iconData: Icons.add,
                  isOutline: false,
                  size: KRButtonSize.small,
                  onPress: () {}))
        ]));
  }
}

==> karot_components-0.0.5.tar.gz: lib/cell/cell_product.dart <==
// ignore_for_file: constant_identifier_names

import 'package:flutter/material.dart';
import 'package:karot_components/button/karot_icon_button.dart';
import 'package:karot_components/constant/button_enum.dart';
import 'package:karot_components/constant/text_enum.dart';
import 'package:karot_components/constant/text_style.dart';
import 'package:karot_components/constant/theme.dart';
import 'package:karot_components/label/karot_label.dart';

class KRCellProduct extends StatelessWidget {
  final String imgURL;
  final String title;
  final String caption;
  final String subtitle;
  final bool isFavorite;
  final EdgeInsetsGeometry padding;
  final int backgroundDiscountColor;
  final int backgroundFavoriteColor;
  final int textColor;
  final String? cartCountText;
  final String? discountText;

  const KRCellProduct({
    Key? key,
    this.imgURL = "http://via.placeholder.com/350x150",
    required this.title,
    required this.subtitle,
    required this.caption,
    this.isFavorite = false,
    this.padding = const EdgeInsets.all(KRTheme.PADDING_NORMAL),
    this.backgroundFavoriteColor = KRTheme.DEFAULT_PRIMARY_LIGHT_COLOR,
    this.backgroundDiscountColor = KRTheme.DEFAULT_PRIMARY_COLOR,
    this.cartCountText,
    this.discountText,
    this.textColor = KRTheme.DEFAULT_DARK_COLOR,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      width: 150,
      height: 200,
        padding: padding,
        child: Stack(children: [
          Column(
            mainAxisAlignment: MainAxisAlignment.start,
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              SizedBox(
                height: 150,
                child: Image.network(
                   imgURL,
                  loadingBuilder: (context, v, url) => const Icon(Icons.emoji_emotions),
                  errorBuilder: (context, url, error) => const Icon(Icons.error),
                ),
              ),
              const SizedBox(height: 10),
              KRLabel(
                  padding: const EdgeInsets.only(left: 10),
                  text: title,
                  isBold: true,
                  size: KRTextSize.body,
                  textAlign: TextAlign.left),
              KRLabel(
                  padding: const EdgeInsets.only(left: 10),
                  text: caption,
                  isBold: false,
                  textColor: KRTheme.DEFAULT_GREY_COLOR,
                  size: KRTextSize.caption,
                  textAlign: TextAlign.left),
              KRLabel(
                  padding: const EdgeInsets.only(left: 10),
                  text: subtitle,
                  isBold: false,
                  size: KRTextSize.body,
                  textAlign: TextAlign.left),
            ],
          ),
          discountText != null ? Positioned(
              left: 5,
              top: 0,
              child: Container(
                  decoration: BoxDecoration(
                      color: Color(backgroundDiscountColor),
                      borderRadius: BorderRadius.circular(10)),
                  padding: const EdgeInsets.all(KRTheme.PADDING_SMALL),
                  child: Text(
                    "30%\nOFF",
                    textAlign: TextAlign.center,
                    style: TStyle.textText(
                        color: const Color(KRTheme.DEFAULT_LIGHT_COLOR),
                        isBold: true,
                        fontSize: KRTextSize.caption),
                  ))) : const SizedBox(),
          Positioned(
              right: -5,
              top: -5,
              child: KRIconButton(
                  backgroundColor: backgroundFavoriteColor,
                  color: isFavorite ? KRTheme.DEFAULT_PRIMARY_COLOR :  KRTheme.DEFAULT_DARK_COLOR,
                  iconData: isFavorite ? Icons.favorite : Icons.favorite_border_sharp,
                  isOutline: false,
                  size: KRButtonSize.small,
                  onPressed: () {})),
          Positioned(
              right: 0,
              top: 110,
              child: KRIconButton(
                text: cartCountText,
                  isCirle: false,
                  backgroundColor: KRTheme.DEFAULT_PRIMARY_LIGHT_COLOR,
                  color: KRTheme.DEFAULT_DARK_COLOR,
                  iconData: Icons.add,
                  isOutline: false,
                  size: KRButtonSize.small,
                  onPressed: () {}))
        ]));
  }
}
